html{font-family:var(--font)!important}.rti--container{max-width:inherit;--rti-tag:var(--primary-color)!important;background-color:var(--secondary-background-color);font:var(--font)}body{color:#fff;background-color:inherit!important;font:var(--font)}h3{color:var(--text-color);background-color:var(--background-color)}span{font:var(--font)}button,span{color:#fff}.rti--input{background-color:var(--secondary-background-color)}
/*# sourceMappingURL=main.07950e13.chunk.css.map */